from django_common_utils.libraries.handlers import HandlerDefinitionType, HandlerMixin
from django_common_utils.libraries.handlers.mixins import WhiteSpaceStripHandler
from django_common_utils.libraries.models import TitleMixin, SlugMixin


class Article(SlugMixin, TitleMixin):
    @staticmethod
    def _COMMON_SLUG_TARGETED_FIELD() -> str:
        return "title"



# Generated by Django 3.0.8 on 2020-07-25 12:22

import django.core.validators
from django.db import migrations, models
import django_common_utils.libraries.handlers.models
import re


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Article',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=127, verbose_name='Title')),
                ('slug', models.SlugField(blank=True, help_text='Representation of the object in the url. Can be left out blank', max_length=127, unique=True, validators=[django.core.validators.RegexValidator(re.compile('^[-a-zA-Z0-9_]+\\Z'), 'Enter a valid “slug” consisting of letters, numbers, underscores or hyphens.', 'invalid')], verbose_name='Slug')),
            ],
            options={
                'abstract': False,
            },
            bases=(django_common_utils.libraries.handlers.models.HandlerMixin, models.Model),
        ),
    ]
